@@ -5,7 +5,7 @@ use swc_atoms::{js_word, JsWord};
 use swc_common::collections::{AHashMap, AHashSet};
 use swc_ecma_ast::{
     CallExpr, Callee, Expr, Ident, KeyValueProp, Lit, MemberExpr, MemberProp, Module, Prop,
-    PropName, Str, StrKind, SuperProp, SuperPropExpr,
+    PropName, Str, SuperProp, SuperPropExpr,
 };
 use swc_ecma_utils::ident::IdentLike;
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith};
@@ -232,7 +232,7 @@ impl Mangler<'_> {
     fn mangle_str(&mut self, string: &mut Str) {
         if let Some(mangled) = self.state.gen_name(&string.value) {
             string.value = mangled;
-            string.kind = StrKind::Synthesized;
+            string.raw = None;
         }
     }
 }
